@@ -1,4 +1,5 @@
 from __future__ import annotations
+from copy import deepcopy
 
 from dataclasses import dataclass
 from typing import Any
@@ -95,7 +96,7 @@ class GrammaticalEvolutionRepresentation(Representation[Genotype]):
         specific_type: type | None = None,
         depth_aware_mut: bool = False,
     ) -> Genotype:
-        return mutate(r, g, ind, depth)
+        return mutate(r, g, deepcopy(ind), depth)
 
     def crossover_individuals(
         self,
@@ -107,7 +108,7 @@ class GrammaticalEvolutionRepresentation(Representation[Genotype]):
         specific_type: type | None = None,
         depth_aware_co: bool = False,
     ) -> tuple[Genotype, Genotype]:
-        return crossover(r, g, i1, i2, depth)
+        return crossover(r, g, deepcopy(i1), deepcopy(i2), depth)
 
     def genotype_to_phenotype(self, g: Grammar, genotype: Genotype) -> TreeNode:
         return create_tree(g, genotype, self.depth, self.method.tree_init_method)
