@@ -40,4 +40,32 @@ class FloatRange(MetaHandlerGenerator):
         return FloatRange(*args)
 
     def __repr__(self):
-        return f"[{self.min}...{self.max}]"
+        return f"[{self.min},{self.max}]"
+
+
+class FloatList(MetaHandlerGenerator):
+    """
+    FloatList([a_1, .., a_n]) restricts floats to be an element from the list [a_1, .., a_n].
+    The range can be dynamically altered before the grammar extraction (Float.__init__.__annotations__["value"] = Annotated[float, FloatList[a_1, .., a_n]].
+    """
+
+    def __init__(self, elements):
+        self.elements = elements
+
+    def generate(
+        self,
+        r: Source,
+        g: Grammar,
+        rec,
+        new_symbol,
+        depth: int,
+        base_type,
+        context: dict[str, str],
+    ):
+        rec(r.choice(self.elements, str(base_type)))
+
+    def __class_getitem__(self, args):
+        return FloatList(*args)
+
+    def __repr__(self):
+        return f"[{self.elements}]"
